===============================
curses-2048
===============================

        
.. image:: http://i.imgur.com/S4F4wgW.png


A terminal/ncurses/python version of the original game at http://gabrielecirulli.github.io/2048

* Free software: GPL license

Install
--------

Open your terminal and type:


.. code:: bash

 $ pip install curses-2048

or 

.. code:: bash  
    
 $ easy_install curses-2048


Usage
--------

.. code:: bash  
    
 $ 2048
  
Use the cursor keys to move and join tiles. Get to the 2048 tile!
